@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use base qw{Power::Outlet::Common::IP::HTTP::JSON};
 
-our $VERSION='0.21';
+our $VERSION='0.22';
 
 =head1 NAME
 
@@ -11,7 +11,7 @@ Power::Outlet::Tasmota - Control and query a Tasmota GIPO configured as a Relay
 
 =head1 SYNOPSIS
 
-  my $outlet = Power::Outlet::Tasmota->new(host => "mybridge", id=>1, username=>"myuser");
+  my $outlet = Power::Outlet::Tasmota->new(host => "tasmota", relay => "POWER");
   print $outlet->query, "\n";
   print $outlet->on, "\n";
   print $outlet->off, "\n";
@@ -20,7 +20,7 @@ Power::Outlet::Tasmota - Control and query a Tasmota GIPO configured as a Relay
 
 Power::Outlet::Tasmota is a package for controlling and querying a relay on Tasmota ESP8266 hardware.
 
-From: https://tasmota.github.io/docs/#/Commands
+From: L<https://tasmota.github.io/docs/#/Commands>
 
 Commands can be executed via web (HTTP) requests, for example:
 
@@ -29,12 +29,6 @@ Commands can be executed via web (HTTP) requests, for example:
   http://<ip>/cm?cmnd=Power%20off
   http://<ip>/cm?user=admin&password=joker&cmnd=Power%20Toggle
 
-Note: Any spaces or special characters must be replaced with their ASCII hex codes. You must precede each hex code with %. Most used ones are: space = %20, ; = %3B
-
-If you have set a password for web user interface access, this must be included (in plaintext) in the URL of the HTTP request, like so:
-
-  http://<ip>/cm?&user=<username>&password=<password>&cmnd=Power%20On
-
 Example: 
 
 
@@ -89,7 +83,7 @@ sub _relay_default {'POWER'};
 
 Sets and returns the hostname or IP address.
 
-Default: mybridge
+Default: tasmota
 
 =cut
 
@@ -120,12 +114,15 @@ sub _http_path_default {'/cm'};
 
 Sets and returns the user used for authentication with the Tasmota hardware
 
-Default: undef #which is only passed on the url when defined
+  my $outlet = Power::Outlet::Tasmota->new(host=>"tasmota", relay=>"POWER", user=>"mylogin", password=>"mypassword");
+  print $outlet->query, "\n";
+
+Default: undef() #which is only passed on the url when defined
 
 =cut
 
 sub user {
-  my $self            = shift;
+  my $self        = shift;
   $self->{'user'} = shift if @_;
   $self->{'user'} = $self->_user_default unless defined $self->{'user'};
   return $self->{'user'};
